.. change::
    :tags: bug, mssql
    :tickets: 9133
    :versions: 2.0.0

    Fixed bug where a schema name given with brackets, but no dots inside the
    name, for parameters such as :paramref:`_schema.Table.schema` would not be
    interpreted within the context of the SQL Server dialect's documented
    behavior of interpreting explicit brackets as token delimiters, first added
    in 1.2 for #2626, when referring to the schema name in reflection
    operations. The original assumption for #2626's behavior was that the
    special interpretation of brackets was only significant if dots were
    present, however in practice, the brackets are not included as part of the
    identifier name for all SQL rendering operations since these are not valid
    characters within regular or delimited identifiers.  Pull request courtesy
    Shan.

